@@ -85,9 +85,13 @@ class Scrutineer:
             post = account.get_post(author, permlink, retries=self._retries)
             if not post:
                 return {}
+
         self.analysis["author"] = author
         self.analysis["permlink"] = permlink
 
+        if self._full:
+            self.analysis["url"] = post["url"]
+
         title = post["title"]
         if not len(title):
             return {}
@@ -180,16 +184,20 @@ def _analyze_title(title, keywords, full=False):
     bmin = length < 20
     amax = length > 80
 
+    score = 0
     skeywords = 0
-    readability = len(cleaned) / length
-    if isinstance(keywords, dict):
-        words = title.lower()
-        for keyword in keywords.keys():
-            if keyword in words:
-                skeywords = 1
-                break
+    readability = 0
+    
+    if length:
+        readability = len(cleaned) / length
+        if isinstance(keywords, dict):
+            words = title.lower()
+            for keyword in keywords.keys():
+                if keyword in words:
+                    skeywords = 1
+                    break
+        score = int(not (bmin or amax)) * (((readability * 9.5) + (skeywords * 0.5)) / 10)
 
-    score = int(not (bmin or amax)) * (((readability * 9.5) + (skeywords * 0.5)) / 10)
     if not full:
         return score
 
@@ -198,8 +206,9 @@ def _analyze_title(title, keywords, full=False):
     analysis["cleaned"] = cleaned
     analysis["below_min"] = bmin
     analysis["above_max"] = amax
+    analysis["keywords"] = keywords
     analysis["readability"] = readability
-    analysis["keywords"] = skeywords
+    analysis["keyword_score"] = skeywords
     analysis["score"] = score
     return analysis
 
